@@ -15,7 +15,7 @@ var _ = Describe("Generating fluentd config", func() {
 	)
 	BeforeEach(func() {
 		var err error
-		generator, err = NewConfigGenerator(true)
+		generator, err = NewConfigGenerator(true, true)
 		Expect(err).To(BeNil())
 		Expect(generator).ToNot(BeNil())
 		forwarding = &logging.ForwardingSpec{
@@ -379,6 +379,10 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @_LEGACY_SECUREFORWARD
 					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SYSLOG
+					</store>
 				</match>
 			</label>
 
@@ -427,6 +431,13 @@ var _ = Describe("Generating fluentd config", func() {
 				@include /etc/fluent/configs.d/secure-forward/secure-forward.conf
 			</match>
 		</label>
+		<label @_LEGACY_SYSLOG>
+			<match **>
+				@type copy
+				#include legacy Syslog
+				@include /etc/fluent/configs.d/syslog/syslog.conf
+			</match>
+		</label>
 	`)
 	})
 
@@ -793,6 +804,10 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @_LEGACY_SECUREFORWARD
 					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SYSLOG
+					</store>
 				</match>
 			</label>
 			<label @_LOGS_AUDIT>
@@ -806,6 +821,10 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @_LEGACY_SECUREFORWARD
 					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SYSLOG
+					</store>
 				</match>
 			</label>
 			<label @_LOGS_INFRA>
@@ -819,6 +838,10 @@ var _ = Describe("Generating fluentd config", func() {
 						@type relabel
 						@label @_LEGACY_SECUREFORWARD
 					</store>
+					<store>
+						@type relabel
+						@label @_LEGACY_SYSLOG
+					</store>
 				</match>
 			</label>
 
@@ -1211,6 +1234,13 @@ var _ = Describe("Generating fluentd config", func() {
 					@include /etc/fluent/configs.d/secure-forward/secure-forward.conf
 				</match>
 			</label>
+			<label @_LEGACY_SYSLOG>
+				<match **>
+					@type copy
+					#include legacy Syslog
+					@include /etc/fluent/configs.d/syslog/syslog.conf
+				</match>
+			</label>
 			`)
 	})
 
