@@ -20,6 +20,6 @@ var (
 	defaultFluentdMemory     resource.Quantity = resource.MustParse("736Mi")
 	defaultFluentdCpuRequest resource.Quantity = resource.MustParse("100m")
 
-	defaultRsyslogMemory     resource.Quantity = resource.MustParse("358Mi")
-	defaultRsyslogCpuRequest resource.Quantity = resource.MustParse("100m")
+	defaultPromTailMemory     resource.Quantity = resource.MustParse("358Mi")
+	defaultPromTailCpuRequest resource.Quantity = resource.MustParse("100m")
 )
